@@ -23,6 +23,7 @@
 
   options(gvis.plot.tag=NULL)
   options(gvis.print.tag="html")
+  options(googleVis.viewer=getOption("viewer"))
 
   ## Set possible gvis.out.options
   ## Output from
@@ -89,15 +90,12 @@ gvisWelcomeMessage <- function(){
         "before you use the package:\n",
         "https://developers.google.com/terms/\n",
         "\n",
-        "Type ?googleVis to access the overall documentation and\n",
-        "vignette('googleVis') for the package vignette.\n",
-        "You can execute a demo of the package via: demo(googleVis)\n",
-        "\n",  
-        "More information is available on the googleVis project web-site:\n",
-        "http://code.google.com/p/google-motion-charts-with-r/\n",
-        "\n",               
-        "Contact: <rvisualisation@gmail.com>\n",
+        "Note, the plot method of googleVis will by default use\n",
+        ifelse(is.null(getOption("viewer")), "the standard browser", 
+               "the RStudio Viewer pane"), " to display its output.\n",
         "\n",
+        "See the googleVis package vignette for more details.\n",
+        "\n",               
         "To suppress the this message use:\n",
         "suppressPackageStartupMessages(library(googleVis))\n",  
           sep="")
